class Management::StatisticsController < ManagementController

  before_action :authenticate_user!, except: [:index, :show, :like]

  def index
    @n_users = User.count
    @n_collections = Collection.count
    @n_learning_objects = LearningObject.count
    @n_complaints = Complaint.count
    @total_accesses= User.sum("sign_in_count")
  end

  def users
    @n_users = User.count
    @n_curators = Role.find_by(name: "curator").users.size
    @n_admins = Role.find_by(name: "admin").users.size
    @n_teachers = Role.find_by(name: "teacher").users.size
  end

  def accesses
    @total_accesses= User.sum("sign_in_count")
  end

  def collections
    @n_collections = Collection.count
    @collections_most_visualised = Collection.order(:views_count)
    @n_collections_non_visualised = Collection.where(views_count: 0).size
  end


  def learning_objects
    @n_learning_objects = LearningObject.count
    @most_visualised = LearningObject.order(:views_count)
    @n_non_visualised = LearningObject.where(views_count: 0).size
    @n_views = LearningObject.sum(:views_count)
  end

  def complaints
    @complaints = Complaint.all
    @n_complaints = Complaint.count
    @complaints_objs = @complaints.map{|complaint| complaint.complaintable.name}.inject(Hash.new(0)) { |h,e| h[e] += 1; h }
    @complaints_per_message = Complaint.group(:complaint_reason).count.reduce({}){ |hash, (k, v)| hash.merge( k.reason => v )  }
  end

end
