module LearningObjectsHelper

  def display_object_type(learning_object)
    case learning_object.object_type.name
      when 'Áudio' then
        audio_tag(learning_object.retrieve_link, controls: true)
      when 'Vídeo' then
        video_tag(learning_object.retrieve_link, autobuffer: true, poster: learning_object.thumbnail)
      when 'PDF' then
        "<iframe src=\"/pdfjs/web/viewer.html?file=#{learning_object.retrieve_link }\" style=\"border: 0 \" width=\"125%\" height=\"280\" frameborder=\"0\" scrolling=\"no\"></iframe>".html_safe
      else
        image_tag learning_object_thumbnail(learning_object, "large"), alt: learning_object_title(learning_object), class: "thumbnail"
    end
  end

  def show_categories(categories = [])
    categories.to_s
  end

  def learning_object_thumbnail(learning_object, size = "")
    if learning_object.thumbnail.blank?
      thumbnail = case learning_object.object_type
                    when "Vídeo" then
                      'video.png'
                    when "Imagem" then
                      'image.png'
                    when "Hipertexto" then
                      'text.png'
                    when "Animação/simulação" then
                      'animation.png'
                    when "Software Educacional" then
                      'software.png'
                    when "Áudio" then
                      'audio.png'
                    when "Experimento prático" then
                      'simulator.png'
                    else
                      if size == "large"
                        'learning-object-preview-large.png'
                      else
                        'learning-object-preview.png'
                      end
                  end
    else
      thumbnail = learning_object.thumbnail
    end
    thumbnail
  end

  def learning_object_title(learning_object)
    if learning_object.name.nil?
      return 'Sem Título'
    end

    learning_object.name
  end

  def render_learning_object(orientation, learning_object)
    case (orientation)
      when "vertical"
        render "learning_objects/learning_object_vertical", learning_object: learning_object
      when "horizontal"
        render "learning_objects/learning_object_horizontal", learning_object: learning_object
      else
        render "learning_objects/learning_object_horizontal", learning_object: learning_object
    end
  end

  def collections_list(learning_object)
    collections = @collections.diff(learning_object_collections(learning_object))
  end

  def social_share(learning_object)
    set_meta_tags og: {
      title: @learning_object.name,
      type:  'website',
      description: @learning_object.description,
      image: @learning_object.thumbnail
    }

    set_meta_tags fb: {
    app_id: '745857965514514'
    }

  end


end
