class LearningObject < ActiveRecord::Base
  include Metadatable
  include Reviewable
  include Sociable
  include Stateful

  has_and_belongs_to_many :topics

  has_many :collection_items, as: :collectionable
  has_many :collections, through: :collection_items
  has_many :complaints
  has_many :attachments, class_name: 'LearningObject::Attachment', dependent: :destroy, autosave: true # autosave to allow import

  belongs_to :publisher, polymorphic: true
  belongs_to :language
  belongs_to :object_type

  validates_presence_of :name, :id_dspace
  validates_uniqueness_of :id_dspace

  searchkick language: 'brazilian', match: :word_start, searchable: [:name, :description, :author, :object_type]

  default_scope { includes(:object_type).order(:score) }

  def search_data
    {
        name: name,
        description: description,
        author: author,
        object_type: object_type.name,
        score: score,
        published_at: published_at,
        topics_name: topics.map(&:name)
    }
  end

  def categories
    get_metadata_value_of 'dc.subject.category'
  end

  def default_attachment
    attachments.where(bundle_name: 'ORIGINAL').first
  end

  def retrieve_link
    "#{DspaceService.link}/rest#{default_attachment.retrieve_link}"
  end

  def url_reference
    get_metadata_value_of 'dc.object.url'
  end

  ##checks if learning object link to an url.
  #returns boolean
  def has_url_reference?
    !url_reference.blank?
  end
end
